@@ -573,7 +573,7 @@ class SQLAlchemyDatabase:
         data: pl.DataFrame,
         mode: t.Literal["RAISE", "IGNORE", "UPDATE"],
         *,
-        chunk_size: int = 100_000,
+        chunk_size: int = 1_000_000,
         returning_id: bool = False,
     ) -> pl.DataFrame | None:
         """
@@ -591,7 +591,6 @@ class SQLAlchemyDatabase:
         pks = self.get_primary_unique_constraint(model_class)
         table = model_class.__table__.name
         cols = data.columns
-        col_list = ", ".join(f'"{c}"' for c in cols)
 
         # Prepare batching
         total_batches = (data.height + chunk_size - 1) // chunk_size
@@ -640,17 +639,26 @@ class SQLAlchemyDatabase:
 
                 temp_table = f"temp_{table}_{batch_idx}"
 
-                # 1) Create temp table (just structure, no constraints/indexes)
-                cursor.execute(f'CREATE TEMP TABLE "{temp_table}" (LIKE "{table}") ON COMMIT DROP')
+                # 1) Create temp table (just structure, no constraints/indexes, exclude auto-generated ID)
+                # Get non-ID columns for temp table
+                non_id_cols = [c for c in cols if c.upper() != "ID"]
+                non_id_col_list = ", ".join(f'"{c}"' for c in non_id_cols)
 
-                # 2) COPY data into staging
+                cursor.execute(
+                    f'CREATE TEMP TABLE "{temp_table}" AS SELECT {non_id_col_list} FROM "{table}" WHERE FALSE'
+                )
+
+                # 2) COPY data into staging (input data shouldn't have ID column)
                 buf = io.StringIO()
                 batch.write_csv(buf)
                 buf.seek(0)
-                cursor.copy_expert(f'COPY "{temp_table}" ({col_list}) FROM STDIN WITH CSV HEADER', buf)
+                cursor.copy_expert(f'COPY "{temp_table}" ({non_id_col_list}) FROM STDIN WITH CSV HEADER', buf)
 
-                # 3) INSERT FROM staging into real table
-                insert_sql = f'INSERT INTO "{table}" ({col_list}) SELECT {col_list} FROM "{temp_table}" ' + on_conflict  # noqa: S608
+                # 3) INSERT FROM staging into real table (only non-ID columns)
+                insert_sql = (
+                    f'INSERT INTO "{table}" ({non_id_col_list}) SELECT {non_id_col_list} FROM "{temp_table}" '
+                    + on_conflict
+                )  # noqa: S608
                 cursor.execute(insert_sql)
 
                 # 4) Optionally retrieve IDs by joining via COPY + Polars
